@@ -85,13 +85,17 @@ sub LDAP_REFERRAL_LIMIT_EXCEEDED   () {	0x61 } # V3
 
 # LDAP Controls
 
-sub LDAP_CONTROL_MANAGEDSAIT       () {	"2.16.840.1.113730.3.4.2"  }
 sub LDAP_CONTROL_SORTREQUEST       () {	"1.2.840.113556.1.4.473"   }
-sub LDAP_CONTROL_SORTRESPONSE      () {	"1.2.840.113556.1.4.474"   }
-sub LDAP_CONTROL_PERSISTENTSEARCH  () {	"2.16.840.1.113730.3.4.3"  }
-sub LDAP_CONTROL_ENTRYCHANGE       () {	"2.16.840.1.113730.3.4.7"  }
+sub LDAP_CONTROL_SORTRESULT        () {	"1.2.840.113556.1.4.474"   }
+
 sub LDAP_CONTROL_VLVREQUEST        () { "2.16.840.1.113730.3.4.9"  }
 sub LDAP_CONTROL_VLVRESPONSE       () {	"2.16.840.1.113730.3.4.10" }
+
+sub LDAP_CONTROL_PAGED		   () { "1.2.840.113556.1.4.319" }
+
+sub LDAP_CONTROL_MANAGEDSAIT       () {	"2.16.840.1.113730.3.4.2"  }
+sub LDAP_CONTROL_PERSISTENTSEARCH  () {	"2.16.840.1.113730.3.4.3"  }
+sub LDAP_CONTROL_ENTRYCHANGE       () {	"2.16.840.1.113730.3.4.7"  }
 # Password information sent back to client
 sub LDAP_CONTROL_PWEXPIRED         () {	"2.16.840.1.113730.3.4.4"  }
 sub LDAP_CONTROL_PWEXPIRING        () {	"2.16.840.1.113730.3.4.5"  }
